@@ -1,12 +1,11 @@
 package Acme::CPANAuthors::DualLife;
-$Acme::CPANAuthors::DualLife::VERSION = '0.36';
+$Acme::CPANAuthors::DualLife::VERSION = '0.38';
 #ABSTRACT: We are CPAN Authors of Dual Life core modules
 
 use strict;
 use warnings;
 
 use Acme::CPANAuthors::Register (
-  ADAMK => q[Adam Kennedy],
   AMBS => q[Alberto Manuel Brandao Simoes],
   AMS => q[Abhijit Menon-Sen],
   ANDK => q[Andreas J. Koenig],
@@ -18,10 +17,8 @@ use Acme::CPANAuthors::Register (
   DAGOLDEN => q[David Golden],
   DANKOGAI => q[Dan Kogai],
   DAPM => q[David A P Mitchell],
-  DLAND => q[David Landgren],
   DROLSKY => q[Dave Rolsky],
   DWHEELER => q[David E. Wheeler],
-  ELIZABETH => q[Elizabeth Mattijsen],
   ETHER => q[Karen Etheridge],
   EXODIST => q[Chad Granum],
   FERREIRA => q[Adriano Ferreira],
@@ -49,6 +46,7 @@ use Acme::CPANAuthors::Register (
   MSHELOR => q[Mark Shelor],
   MUIR => q[David Muir Sharnoff],
   NEILB => q[Neil Bowers],
+  NTHYKIER => q[Niels Thykier],
   NWCLARK => q[Nicholas Clark],
   OVID => q[Curtis 'Ovid' Poe],
   PEVANS => q[Paul Evans],
@@ -56,6 +54,7 @@ use Acme::CPANAuthors::Register (
   PJF => q[Paul Jamieson Fenwick],
   PMQS => q[Paul Marquess],
   RGARCIA => q[Rafael Garcia-Suarez],
+  RICHE => q[Richard Elberger],
   RJBS => q[Ricardo SIGNES],
   RMBARKER => q[Robin Barker],
   RRA => q[Russ Allbery],
@@ -89,7 +88,7 @@ Acme::CPANAuthors::DualLife - We are CPAN Authors of Dual Life core modules
 
 =head1 VERSION
 
-version 0.36
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -112,7 +111,6 @@ It is currently statically generated information, I hope to make it dynamic in t
 
 =head1 CONTAINED AUTHORS
 
-  ADAMK => q[Adam Kennedy],
   AMBS => q[Alberto Manuel Brandao Simoes],
   AMS => q[Abhijit Menon-Sen],
   ANDK => q[Andreas J. Koenig],
@@ -124,10 +122,8 @@ It is currently statically generated information, I hope to make it dynamic in t
   DAGOLDEN => q[David Golden],
   DANKOGAI => q[Dan Kogai],
   DAPM => q[David A P Mitchell],
-  DLAND => q[David Landgren],
   DROLSKY => q[Dave Rolsky],
   DWHEELER => q[David E. Wheeler],
-  ELIZABETH => q[Elizabeth Mattijsen],
   ETHER => q[Karen Etheridge],
   EXODIST => q[Chad Granum],
   FERREIRA => q[Adriano Ferreira],
@@ -155,6 +151,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   MSHELOR => q[Mark Shelor],
   MUIR => q[David Muir Sharnoff],
   NEILB => q[Neil Bowers],
+  NTHYKIER => q[Niels Thykier],
   NWCLARK => q[Nicholas Clark],
   OVID => q[Curtis 'Ovid' Poe],
   PEVANS => q[Paul Evans],
@@ -162,6 +159,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   PJF => q[Paul Jamieson Fenwick],
   PMQS => q[Paul Marquess],
   RGARCIA => q[Rafael Garcia-Suarez],
+  RICHE => q[Richard Elberger],
   RJBS => q[Ricardo SIGNES],
   RMBARKER => q[Robin Barker],
   RRA => q[Russ Allbery],
@@ -192,7 +190,7 @@ Chris Williams
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Chris Williams.
+This software is copyright (c) 2015 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
